sciduck.annotation_table module — sciduck documentation

# sciduck.annotation_table module

sciduck.annotation_table.add_dominant_library_info(adata: AnnData, mapping_summary: dict) → dict

  Add dominant library information to the mapping summary.

  Parameters:

    - adata – Anndata object with annotations in obs.

    - mapping_summary – A pre-existing mapping summary dictionary to add information on dominant library.

  Returns:

    A mapping_summary containing dominant library information.

sciduck.annotation_table.build_annotation_table(adata: AnnData, categorical_annotations: list = ['donor_name', 'load_name', 'roi'], numeric_annotations: list = ['doublet_score', 'pct_counts_mt'], min_percent: float = 0.05, annotation_alerts: dict = {'donor_name': 0.9, 'load_name': 0.95, 'roi': 0.95}, add_dominant_library_info: bool = True, add_entropy_info: bool = True, mapping_summary: dict = {}) → dict

  Build a standardized table of annotations describing each cluster to be used for taxonomy development or communication.

  Parameters:

    - adata – Anndata object with annotations in obs.

    - annotations – Cluster summary annotations specific to data.

    - mapping_summary – A dictionary to store the mapping summary. User can pass in an existing dictionary to append to if desired.

  Returns:

    A mapping_summary containing character and numeric summaries along with donor/lib/roi composition alerts.